/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Can not combine \"allow external\" and \"allow only members\""
: ""

, "Delete"
: "ลบ"

, "Reply"
: "ตอบ"

, "Reply To All"
: "ตอบทุกคน"

, "Forward"
: "ส่งต่อ"

, "Print Message"
: "พิมพ์ข้อความ"

, "Print Preview"
: "พิมพ์หน้าพรีวิว"

, "Add New Account"
: ""

, "Permissions"
: ""

, "Rules"
: ""

, "Vacation, Vacations"
: [
  "พักร้อน"

]
, "Account, Accounts"
: [
  "บัญชี"

]
, "Account Name"
: "ชื่อบัญชี"

, "Type"
: ""

, "Migration Approved"
: ""

, "Approve Migration"
: ""

, "Do you want to approve the migration of this account?"
: ""

, "User"
: ""

, "User Email"
: "อีเมลของผู้ใช้"

, "User Name (From)"
: "ชื่อผู้ใช้ (จาก)"

, "Organization"
: "องค์กร"

, "Signature position"
: "ตำแหน่งของลายเซ็นต์"

, "Above the quote"
: "เหนือคำที่อ้างมา"

, "Below the quote"
: "ใต้คำที่อ้างมา"

, "IMAP"
: "IMAP"

, "Host"
: "แม่ข่าย"

, "Port (Default: 143 / SSL: 993)"
: "พอร์ต (Default: 143 / SSL: 993)"

, "Secure Connection"
: "การเชื่อมต่อที่ปลอดภัย"

, "None"
: "ไม่มีเลย"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Username"
: "ชื่อผู้ใช้"

, "Password"
: "รหัสผ่าน"

, "Test IMAP Connection"
: ""

, "SMTP"
: "SMTP"

, "Port (Default: 25)"
: "พอร์ต (Default: 25)"

, "Authentication"
: "การอนุญาต"

, "Login"
: "ลงบันทึกเข้า"

, "Plain"
: "ธรรมดา"

, "Username (optional)"
: "ชื่อผู้ใช้ (ไม่บังคับ)"

, "Password (optional)"
: "รหัสผ่าน (ไม่บังคับ)"

, "Test SMTP Connection"
: ""

, "Sieve"
: "กรอง"

, "Port (Default: 2000)"
: "พอร์ต (Default: 2000)"

, "Notification Email"
: ""

, "Auto-move notifications"
: ""

, "Auto-move notifications folder"
: ""

, "Other Settings"
: "ค่าติดตั้งอื่น ๆ"

, "Sent Folder Name"
: "ชื่อของแฟ้ม ส่งแล้ว"

, "Trash Folder Name"
: "ชื่อของแฟ้ม ขยะ"

, "Drafts Folder Name"
: "ชื่อของแฟ้ม โครงร่าง"

, "Templates Folder Name"
: "ชื่อของแฟ้มแม่แบบ"

, "Display Format"
: "รูปแบบที่ใช้"

, "HTML"
: "HTML"

, "Plain Text"
: "ข้อความธรรมดา"

, "Depending on content type (experimental)"
: "ขึ้นอยู่กับประเภทเนื้อหา (ช่วงทดลอง)"

, "Compose Format"
: ""

, "Preserve Format"
: ""

, "No"
: ""

, "Yes"
: ""

, "Reply-To Email"
: ""

, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
: ""

, "Migration has not been approved."
: ""

, "It is not possible to convert the account to this type."
: ""

, "System accounts cannot be created manually."
: ""

, "Mailinglist accounts cannot be created manually."
: ""

, "Account type change not possible"
: ""

, "E-Mail account needs a password"
: ""

, "Use"
: ""

, "The grant use the shared email account"
: ""

, "Edit"
: ""

, "The grant edit the shared email account"
: ""

, "Send Mails"
: ""

, "The grant to send mails via the email account"
: ""

, "Warning"
: ""

, "Server connection failed. Do you still want to save this setting and exit?"
: ""

, "Connection succeed"
: ""

, "Connecting to {0} server..."
: ""

, "Connection failed"
: ""

, "{server} Connection Status"
: ""

, "Save Message as"
: ""

, "File (in Filemanager) ..."
: ""

, "Attachment (of Record)"
: ""

, "Download"
: ""

, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
: ""

, "Success"
: ""

, "Error"
: ""

, "Save Messages as Attachment"
: ""

, "No Messages found."
: ""

, "It is SPAM"
: ""

, "It is not SPAM"
: ""

, "Compose"
: "เขียน"

, "Toggle highlighting"
: "เปิดปิดการเน้นให้เด่น"

, "Mark read/unread"
: "ทำเครื่องหมาย อ่านแล้ว/ ยังไม่ได้อ่าน"

, "Move"
: ""

, "Copy"
: ""

, "Import Messages"
: ""

, "Add Account"
: "เพิ่มบัญชี"

, "No target folder selected"
: ""

, "You need to select a target folder for the messages."
: ""

, "Wrong File Type"
: ""

, "Files of type eml allowed only."
: ""

, "Importing Messages..."
: ""

, "Id"
: "รหัส"

, "Attachments"
: "สิ่งที่แนบมาด้วย"

, "Flags"
: "ป้าย"

, "Subject"
: "หัวเรื่อง"

, "From (Email)"
: "จาก (อีเมล)"

, "From (Name)"
: "จาก (ชื่อ)"

, "Sender"
: "ผู้ส่ง"

, "To"
: "ถึง"

, "Sent"
: "ส่งแล้ว"

, "Received"
: "ได้รับแล้ว"

, "Folder, Folders"
: [
  "แฟ้มเอกสาร"

]
, "Size"
: "ขนาด"

, "Answered"
: "ตอบแล้ว"

, "Forwarded"
: "ส่งต่อแล้ว"

, "This message might be SPAM"
: ""

, "Tine20"
: ""

, "Encrypted Message"
: ""

, "Filed as:"
: ""

, "Select Message File Location"
: ""

, "Filing Messages"
: ""

, "Error Filing Message"
: ""

, "Could not file message."
: ""

, "Send Reading Confirmation"
: "ส่งการยืนยันการอ่าน"

, "Do you want to send a reading confirmation message?"
: "คุณต้องการส่งข้อความยืนยันการอ่านหรือไม่?"

, "Empty Folder"
: "ล้างแฟ้ม"

, "Add Folder"
: "เพิ่มแฟ้ม"

, "New {0}"
: "ใหม่ {0}"

, "Please enter the name of the new {0}:"
: "กรุณาใส่ชื่อของ {0} ใหม่:"

, "No {0} added"
: "ไม่ได้ {0} เพิ่ม"

, "You have to supply a {0} name!"
: "คุณต้องใช้ชื่อ {0} หนึ่ง!"

, "Please wait"
: "กรุณารอ"

, "Creating {0}..."
: "กำลังสร้าง {0}..."

, "Edit Account"
: "แก้ไขบัญชี"

, "Edit Vacation Message"
: "แก้ไขข้อความลาพัก"

, "Edit Filter Rules"
: "แก้ไขระเบียบตัวกรอง"

, "Notifications"
: ""

, "Mark Folder as read"
: "ทำเครื่องหมายแฟ้มว่าอ่านแล้ว"

, "Update Folder List"
: "ปรับปรุงรายชื่อแฟ้ม"

, "Message not available."
: "ข้อความไม่มีอยู่ "

, "Cancel"
: "ยกเลิก"

, "Ok"
: "ตกลง"

, "Folders of account {0}"
: "แฟ้มของบัญชี {0}"

, "Folders of all accounts"
: "แฟ้มของทุกบัญชี"

, "Compose email"
: "เขียนอีเมล"

, "CC"
: ""

, "BCC"
: ""

, "Mass Mailing"
: ""

, "Open in Felamimail"
: ""

, "From"
: "จาก"

, "Add"
: "เพิ่ม"

, "Add contact to addressbook"
: "เพิ่มการติดต่อไปยังสมุดที่อยู่"

, "Date"
: "วันที่"

, "Show or hide header information"
: "แสดงหรือซ่อนหัวข้อของข้อมูล"

, "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
: ""

, "Open"
: ""

, "Save As"
: ""

, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
: ""

, "Save as Record Attachment"
: ""

, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
: ""

, "Confirm SPAM Suspicion"
: ""

, "Yes, it is SPAM"
: ""

, "No, it is not"
: ""

, "(new message)"
: "(ข้อความใหม่)"

, "Select recipients for \"{0}\""
: "เลือกผู้รับสำหรับ \"{0}\""

, "Signatures"
: ""

, "Name"
: ""

, "Is Default"
: ""

, "Add Signature"
: ""

, "Edit Signature"
: ""

, "Delete Signature"
: ""

, "Recipient filter"
: "ตัวกรองผู้รับ"

, "All recipients"
: "ผู้รับทั้งหมด"

, "\"{0}\" recipients"
: "\"{0}\" ผู้รับ"

, "Attachment"
: ""

, "Filemanager (Download link)"
: ""

, "Filemanager (Download link, password)"
: ""

, "Filemanager (Systemlink)"
: ""

, "Attachment Type"
: ""

, "Click icon to change"
: ""

, "name"
: ""

, "size"
: ""

, "type"
: ""

, "Vacation Message for {0}"
: "ข้อความลาพักสำหรับ {0}"

, "Notification for {0}"
: ""

, "Move up"
: "ย้ายขึ้น"

, "Move down"
: "ย้ายลง"

, "Enable"
: "สามารถใช้งานได้"

, "Disable"
: "ไม่สามารถใช้งานได้"

, "ID"
: "รหัส"

, "Conditions"
: "เงื่อนไข"

, "Action"
: "ปฏิกิริยา"

, "Keep a copy"
: ""

, "is greater than"
: "มากกว่า"

, "is less than"
: "น้อยกว่า"

, "Header \"{0}\" contains \"{1}\""
: "หัวเรื่อง \"{0}\" มี \"{1}\""

, "Header \"{0}\" matches \"{1}\""
: "หัวเรื่อง \"{0}\" ตรงกับ \"{1}\""

, "Sieve Filter Rules"
: "กรองระเบียบตัวกรอง"

, "Sieve Filter Rules for {0}"
: "กรองระเบียบตัวกรองสำหรับ {0}"

, "From (Email and Name)"
: "จาก (อีเมลและชื่อ)"

, "To (Email)"
: "ถึง (อีเมล)"

, "To (Email CC)"
: "ถึง (อีเมล CC)"

, "Header contains"
: "หัวเรื่องบรรจุ"

, "Header name"
: "ชื่อหัวเรื่อง"

, "Header value"
: "ค่าหัวเรื่อง"

, "Header regex"
: "นิพจน์ปรกติของหัวเรื่อง"

, "Edit Filter Rule"
: "แก้ไขระเบียบตัวกรอง"

, "Apply filter if"
: "ใช้ตัวกรองในกรณี"

, "all conditions match"
: "ตรงตามทุกเงื่อนไข"

, "any condition matches"
: "ตรงกับเงื่อนไขใดๆก็ได้"

, "Do this action:"
: "ทำสิ่งนี้:"

, "Move mail to folder"
: "ย้ายเมลไปแฟ้ม"

, "Redirect mail to address"
: "เปลี่ยนส่งเมลไปยังที่อยู่"

, "Reject mail with this text"
: "ปฏิเสธเมลที่มีเนื้อเความนี้อยู่"

, "Discard mail"
: "กำจัดเมล"

, "Auto-Reply mail with this text"
: ""

, "Keep mail"
: "เก็บเมล"

, "General"
: "ทั่วไป"

, "Advanced"
: "ก้าวหน้า"

, "Only send all X days to the same sender"
: "ส่งเฉพาะ X วันทั้งหมดไปยังผู้ส่งคนเดิม"

, "Incoming mails will be answered with this text:"
: "เมลที่เข้ามาจะได้รับคำตอบด้วยเนื้อหานี้:"

, "Status"
: "สถานะ"

, "I am available (vacation message disabled)"
: "ฉันว่าง (ข้อความพักร้อน ถูกปิด)"

, "I am not available (vacation message enabled)"
: "ฉันไม่ว่าง (ข้อความพักร้อน ถูกเปิด)"

, "Start Date"
: "วันที่เริ่มต้น"

, "Set vacation start date ..."
: "ตั้งวันที่เริ่มต้นพักร้อน"

, "End Date"
: "วันที่สิ้นสุด"

, "Set vacation end date ..."
: "ตั้งวันที่สิ้นสุดพักร้อน ..."

, "Representative #1"
: "ตัวแทน #1"

, "Choose first Representative ..."
: "เลือกตัวแทนที่หนึ่ง ..."

, "Representative #2"
: "ตัวแทน #2"

, "Choose second Representative ..."
: "เลือกตัวแทนที่สอง ..."

, "Message Template"
: "แม่แบบข้อความ"

, "Choose Template ..."
: "เลือกแม่แบบ ..."

, "Mailvelope decryption Error [{0}]"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "GENDER_Message"
: ""

, "Message, Messages"
: [
  "ข้อความ"

]
, "Subject/From"
: "หัวเรื่อง/ จาก"

, "Cc"
: "Cc"

, "Bcc"
: "Bcc"

, "INBOX"
: "กล่องข้อความเข้า"

, "Drafts"
: "โครงร่าง"

, "Templates"
: "แม่แบบ"

, "Junk"
: "ขย"

, "Trash"
: "ขยะ"

, "GENDER_Folder"
: ""

, "record list, record lists"
: [
  "บันทึกรายชื่อ"

]
, "Rule, Rules"
: [
  "ระเบียบ"

]
, "Flag, Flags"
: [
  "ป้าย"

]
, "Flag list, Flag lists"
: [
  "รายชื่อป้ายต่างๆ"

]
, "Total Messages:"
: "ข้อความทั้งหมด:"

, "Unread Messages:"
: "ข้อความที่ยังไม่ได้อ่าน:"

, "Name on Server:"
: "ชื่อบนเซิร์ฟเวอร์:"

, "Last update:"
: "ปรับปรุงล่าสุด:"

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  "{0} ข้อความที่ยังไม่ได้อ่าน"

]
, "New Mail"
: "เมลใหม่"

, "Email"
: "อีเมล"

, "Active Vacation Message"
: "ข้อความลาพักที่ใช้อยู่"

, "Email account \"{0}\" has an active vacation message."
: "บัญชีอีเมล \"{0}\" มีข้อความที่ใช้สำหรับพักร้อนเปิดอยู่"

, "Poll URL: {0}"
: ""

, "{0} as default mailer"
: ""

, "New mails"
: "เมลใหม่"

, "You got {0} new mail(s) in folder {1} ({2})."
: "คุณมี {0} เมลใหม่(s) ในแฟ้ม {1} ({2})"

, "IMAP Credentials for {0}"
: "IMAP อ้างอิงสำหรับ {0}"

, "Credentials"
: "ตัวอ้างอิง"

, "IMAP Error"
: "ข้อผิดพลาด IMAP"

, "No connection to IMAP server."
: "ไม่มีการติดต่อไปยังเซิร์ฟเวอร์ IMAP"

, "IMAP Credentials Error"
: "IMAP ตัวอ้างอิงผิดพลาด"

, "Your email credentials are wrong. Please contact your administrator"
: "ตัวอ้างอิงอีเมลของคุณผิด กรุณาติดต่อผู้ดูแลระบบ"

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: "หนึ่งในแฟ้มของคุณถูกลบหรือโดนเปลี่ยนชื่อโดยผู้ใช้คนอื่น กรุณาอัพเดทรายชื่อแฟ้มของบัญชีนี้"

, "SMTP Error"
: "ข้อผิดพลาด SMTP"

, "No connection to SMTP server."
: "ไม่มีการติดต่อไปยังเซิร์ฟเวอร์ SMTP"

, "Sieve Error"
: "กรองข้อผิดพลาด"

, "No connection to Sieve server."
: "ไม่มีการติดต่อไปยังเซิร์ฟเวอร์ที่กรอง"

, "Save Sieve Script Error"
: "จัดเก็บตัวกรองข้อผิดพลาดด้านสคริป"

, "Could not save script on Sieve server."
: "ไม่สามารถจัดเก็บสคริปบนตัวให้บริการกรอง"

, "Add as \"To\""
: "เพิ่มเป็น \"To\""

, "Add as \"Cc\""
: "เพิ่มเป็น \"Cc\""

, "Add as \"Bcc\""
: "เพิ่มเป็น \"Bcc\""

, "Remove from recipients"
: "เอาออกจากผู้รับ"

, "Loading Mail Addresses"
: "กำลังโหลดที่อยู่อีเมล"

, "Click here to set To/CC/BCC."
: "กดที่นี่เพื่อตั้งเป็น To/CC/BCC"

, "To:"
: "To:"

, "Cc:"
: "Cc:"

, "Bcc:"
: "Bcc:"

, "Remove"
: "เอาออก"

, "Send"
: "ส่ง"

, "Search Recipients"
: "ค้นหาผู้รับ"

, "Save As Draft"
: "บันทึกเป็นโครงร่าง"

, "Save As Template"
: "บันทึกเป็นแม่แบบ"

, "Reading Confirmation"
: "การยืนยันการอ่าน"

, "Activate this toggle button to receive a reading confirmation."
: "ใช้ปุ่มเปิดปิดนี้เพื่อรับการยืนยันการอ่าน"

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Activate this toggle button to send the mail as separate mail to each recipient."
: ""

, "Click to search for and add recipients from the Addressbook."
: "กดปุ่สำหรับค้นหาและเพิ่มผู้รับจากสมุดที่อยู่"

, "Encrypted Content"
: ""

, "Discard this Draft?"
: ""

, "Do you want to discard the current draft?"
: ""

, "Fwd:"
: "ส่งต่อ:"

, "{0} Message"
: "{0} ข้อความ"

, "Failed"
: "ได้ล้มเหลว"

, "{0} account setting empty."
: "ค่าติดตั้งบัญชี {0} ว่าง"

, "Files are still uploading."
: "ยังคงอัปโหลดไฟล์อยู่"

, "{locationCount, plural, one {This message will be filed at the following location} other {This message will be filed at the following locations}}: {locationsHtml}"
: ""

, "On {0}, {1} wrote"
: "บน {0}, {1} ได้เขียนแล้ว"

, "Original message"
: "ข้อความดั้งเดิม"

, "Compose email:"
: "เขียนอีเมล:"

, "Convert to formated text"
: ""

, "Body"
: "ข้อความ"

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: ""

, "Add email address here for reply-to"
: ""

, "Signature, Signatures"
: [
  ""

]
, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: ""

, "Do you really want to send?"
: ""

, "Empty subject"
: "ล้างหัวเรื่อง"

, "Do you really want to send a message with an empty subject?"
: "คุณแน่ใจว่าต้องการส่งข้อความที่ไม่มีหัวเรื่อง"

, "No recipients set."
: "ไม่ได้ตั้งผู้รับ"

, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "All inboxes"
: "กล่องข้อความเข้าทั้งหมด"

, "Default Email Account"
: "บัญชีอีเมลหลัก"

, "The default email account to use when sending mails."
: "บัญชีอีเมลหลักที่ใช้ส่งอีเมล"

, "Mark Email Automatically As Read"
: ""

, "Is email marked as read automatically or by user action"
: ""

, "Email Update Interval"
: "ความถี่ในการอัพเดทอีเมล"

, "How often should Felamimail check for new Emails (in minutes)."
: "ต้องการให้ Felamimail เช็คอีเมลใหม่ บ่อยแค่ไหน (เป็นนาที)"

, "Use for mailto links"
: "ใช้สำหรับเชื่อมต่อ เมลไปยัง"

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: "ใช้ Felamimail ในการเชื่อมต่อเมลไปยัง หรือไม่ก็ใช้ค่าหลักที่ลูกค้าตั้งไว้บนเดสก์ท็อป"

, "Use for NOTES"
: "ใช้สำหรับบันทึก"

, "Save Note default Value."
: "ค่าหลักของบันทึกโน๊ต"

, "Confirm Delete"
: "ยืนยันการลบ"

, "Show confirmation dialog when deleting mails."
: "แสดงข้อความยืนยันเมื่อกำลังลบเมล"

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Default Font"
: ""

, "Setting the default font in the E-Mail app"
: ""

, "Mail Type"
: ""

, "Possible mail types."
: ""

, "Additional Personal External Account"
: ""

, "Shared System Account"
: ""

, "Additional Personal System Account"
: ""

, "Default Personal System Account"
: ""

, "Mailinglist"
: ""

, "Mailinglist Reject Reason"
: ""

, "Your email has been rejected"
: ""

, "Vacation Templates Node ID"
: ""

, "Email Notification Templates Node ID"
: ""

, "Custom Vacation Message"
: "จัดทำข้อความพักร้อน"

, "User is allowed to set custom vacation message for system account"
: "ผู้ใช้สามารถตั้งข้อความพักร้อนด้วยตัวเองสำหรับบัญชีระบบได้"

, "Cache email body"
: "แคชข้อความของอีเมล"

, "Should the email body be cached (recommended for slow IMAP server connections)"
: "ควรให้ข้อความของอีเมลมีการจัดเก็บ (แนะนำสำหรับการติดต่อระบบ IMAP ที่ล่าช้า)"

, "Delete Archived Mail"
: ""

, "Prevent copying mails in the same account"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Felamimail Application."
: ""

, "Account Migration"
: ""

, "Shows context menu for system accounts to approve migration"
: ""

, "Move notifications"
: ""

, "Move notifications to a subfolder via sieve"
: ""

, "Auto-Save Drafts"
: ""

, "Save drafts automatically while editing an email"
: ""

, "Only password download link"
: ""

, "Allow only password download link"
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Show Reply-To"
: ""

, "Show Reply-To field in message compose dialog"
: ""

, "Auto-Create Folders"
: ""

, "Create template, trash, sent, draft and junks folders for system accounts"
: ""

, "Enable Spam Suspicion Strategy"
: ""

, "SEnable pam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy Config"
: ""

, "Spam User Processing Pipeline"
: ""

, "Confirm SPAM Suspicion Message"
: ""

, "Message for users when they press the info button in a SPAM suspicion toolbar."
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: ""

, "System Account Folder Defaults"
: ""

, "Paths of the special folders (like Sent, Trash, ...)"
: ""

, "Allow self signed TLS cert for IMAP connection"
: ""

, "Sieve Redirect Only Internal"
: ""

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: ""

, "Sieve Notification Bounces Reporting Email"
: ""

, "URL icon path for own domain"
: ""

, "Used to mark messages from configured primary and secondary domains"
: ""

, "URL icon path for other domains"
: ""

, "Used to mark messages from all other domains"
: ""

, "Other domain regex for FLAG_ICON_OTHER_DOMAIN"
: ""

, "shared / adb_list accounts need to have a password set"
: ""

, "Is default"
: ""

, "Email Account, Email Accounts"
: [
  ""

]
, "IMAP Host"
: ""

, "IMAP Port"
: ""

, "IMAP SSL"
: ""

, "Sent Folder"
: ""

, "Trash Folder"
: ""

, "Drafts Folder"
: ""

, "Templates Folder"
: ""

, "Reply-To"
: ""

, "E-Mail"
: ""

, "Signature Position"
: ""

, "SMTP Host"
: ""

, "SMTP Port"
: ""

, "SMTP SSL"
: ""

, "SMTP Authentication"
: ""

, "Sieve Host"
: ""

, "Sieve Port"
: ""

, "Sieve SSL"
: ""

, "Reading Confirmation:"
: "การยืนยันการอ่าน:"

, "Your message:"
: "ข้อความของคุณ:"

, "Received on"
: "ได้รับแล้วเมื่อ"

, "Was read by:"
: "ได้อ่านแล้ว โดย:"

, "on"
: "เมื่อ"

, "Message File Location, Message File Locations"
: [
  ""

]
, "Message File Locations"
: ""

, "Message ID Hash"
: ""

, "Message ID"
: ""

, "Model"
: ""

, "Record ID"
: ""

, "Record Title"
: ""

, "Node ID"
: ""

, "Message File Suggestion, Message File Suggestions"
: [
  ""

]
, "Message File Suggestions"
: ""

, "Out of Office reply from %1$s"
: "ไม่ได้อยู่ที่บริษัท ตอบจาก %1$s"

, "It is not allowed to redirect emails to self! Please change the recipient."
: ""

, "Redirects to external email domains are not allowed."
: ""

, "You have new mail from "
: ""

, "shared / adb_list accounts need to have an email set"
: ""

, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
: ""

, "userInternal accounts need to have an email set"
: ""

, "userInternal accounts need to have an user_id set"
: ""

, "Please choose a new email address for userInternal accounts"
: ""

, "system account for user does not exist"
: ""

, "Account type cannot be changed from {0} to {1}"
: ""

, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
: ""

, "Migration of this account has not been approved!"
: ""

, "Could not find email user xprops!"
: ""

, "Internal user accounts need a valid user"
: ""

, "System account of user is missing"
: ""

, "Bad recipient address syntax"
: ""

, "Recipient address rejected"
: ""

, "Original message not found, email was moved or deleted"
: ""

, "Invalid address format"
: ""

, "Error: %s"
: "ข้อผิดพลาด: %s"

, "Could not send message"
: "ไม่สามารถส่งข้อความได้"

, "My Mail Download Links"
: ""

, "Seen"
: "เห็นแล้ว"

, "Deleted"
: "ลบแล้ว"

, "Draft"
: "โครงร่าง"

, "Flagged"
: "ติดป้ายชื่อแล้ว"

, "It is not allowed to copy e-mails in the same account."
: ""

, "Folder with name {0} already exists!"
: ""

, "Failure on create folder"
: ""

, "All inboxes of my email accounts"
: "แสดงกล่องข้อความเข้าทั้งหมดของบัญชีอีเมลฉัน"

, "All unread mail"
: "เมลที่ยังไม่ได้อ่านทั้งหมด"

, "All unread mail of my email accounts"
: "เมลที่ยังไม่ได้อ่านทั้งหมดของบัญชีอีเมลฉัน"

, "All highlighted mail"
: "ทุกอีเมลที่ได้เน้นให้เด่น"

, "All highlighted mail of my email accounts"
: "ทุกอีเมลที่ได้เน้นให้เด่นของบัญชีอีเมลของฉัน"

, "All drafts"
: "โครงร่างทั้งหมด"

, "All mails with the draft flag"
: "เมลทั้งหมดที่มีป้ายร่าง"

, "IMAP Hostname missing"
: ""

, "IMAP Credentials missing"
: ""

, "SMTP Hostname missing"
: ""

, "SMTP Credentials missing"
: ""

, "manage email accounts"
: "จัดการบัญชีอีเมล"

, "Edit and delete email accounts"
: "แก้ไขและลบบัญชีอีเมล"

, "Add email accounts"
: "เพิ่มบัญชีอีเมล"

, "Create new email accounts"
: "สร้างบัญชีอีเมลใหม่"

, "Vacation"
: "พักร้อน"

, "Account"
: "บัญชี"

, "Folder"
: "แฟ้มเอกสาร"

, "Message"
: "ข้อความ"

, "record list"
: "บันทึกรายชื่อ"

, "Rule"
: "ระเบียบ"

, "Flag"
: "ป้าย"

, "Flag list"
: "รายชื่อป้ายต่างๆ"

, "{0} unread message"
: "{0} ข้อความที่ยังไม่ได้อ่าน"

, "Signature"
: ""

, "Email Account"
: ""

, "Message File Location"
: ""

, "Message File Suggestion"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
